<?php

// $Id: exerciseplan_form.page.inc,v 1.28.2.6 2010/10/05 13:03:52 icc Exp $

/**
 * The exercise plan's form page
 */
function exerciseplan_form_page() {
  drupal_add_js(drupal_get_path('module', 'exerciseplan') . '/js/mousewheel.js');
  drupal_add_js(drupal_get_path('module', 'exerciseplan') . '/js/jScrollPane-1.2.2.js');
  drupal_add_js(drupal_get_path('module', 'exerciseplan') . '/js/jquery.bltcheckbox.js');
  drupal_add_js(drupal_get_path('module', 'exerciseplan') . '/js/jquery.textOverflow.0.1.1.js');
  drupal_add_js(
    array(
      'exerciseplan' => array(
        'url' => url('exerciseplan'),
        'skipFirstStep' => variable_get('exerciseplan_skip_first_step', 0),
        'perodicExample' => variable_get('exerciseplan_perodic_example', ''),
        'workoutExample' => variable_get('exerciseplan_workout_example', '')
      ),
      'exercise' => array(
        'url' => url('exercise')
      )
    ),
    'setting'
  );
  drupal_add_js(drupal_get_path('module', 'exerciseplan') . '/js/exerciseplan.js');
  return drupal_get_form('exerciseplan_form');
}

/**
 * The form for creating an exercise plan. This form will be made into a
 * multistep form using javascript. We're using javascript for this to improve
 * performance and scalability.
 */
function exerciseplan_form(&$form_state) {
  /* 2nd step, choose plan name and type */
  $form['plan_name'] = array(
    '#type' => 'textfield',
    '#maxlength' => 64,
  );
  $form['plan_type'] = array(
    '#type' => 'radios',
    '#options' => array(t('Workout plan - warm up plan'), t('Perodic plan - weekly schedule')),
  );

  /* 3rd step, perodic plan */
  $form['plan_objective'] = array(
    '#type' => 'textfield',
    '#title' => t('Objective'),
    '#maxlength' => 256,
    '#size' => 60.
  );
  // Week number
  $week = date('W');
  $form['plan_' . $week] = array(
    '#type' => 'textfield',
    '#default_value' => $week,
    '#maxlength' => 2,
  );

  // Add one week
  for ($i = 0; $i < 7; $i++) {
    $form['plan_' . $week . '_' . $i . '_0'] = array(
      '#type' => 'textfield',
      '#maxlength' => 30,
    );
  }

  /* 5th step, create a detailed plan for a workout session */
  $form['exercise_plan_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Topic'),
    '#maxlength' => 64,
    '#size' => 14,
  );
  $form['exercise_plan_date'] = array(
    '#type' => 'textfield',
    '#title' => t('Date'),
    '#maxlength' => 32,
    '#size' => 8,
  );
  $form['exercise_plan_objective'] = array(
    '#type' => 'textfield',
    '#title' => t('Objective'),
    '#maxlength' => 64,
    '#size' => 48,
  );
  $form['exercises'] = array(
    '#type' => 'hidden',
    '#value' => '',
  );
  $form['exercise_amount'] = array(
    '#type' => 'textarea',
    '#cols' => '20',
    '#rows' => '4',
  );
  $form['exercise_why'] = array(
    '#type' => 'textarea',
    '#cols' => '25',
    '#rows' => '4',
  );

  /* 6th step, exercise library */
  $vid = variable_get('exerciseplan_vocabulary', NULL);
  $all_terms = taxonomy_get_tree($vid);

  // Translate localized terms
  $options = variable_get('i18ntaxonomy_vocabulary', array($vid => 0));
  if ($options[$vid] == 1) {
    $all_terms = i18ntaxonomy_localize_terms($all_terms);
  }

  $form = exerciseplan_init_filters($all_terms, $form);

  // Submit button (we need a submit button even if we're not going to use it)
  $form['submit'] = array(
    '#type' => 'submit',
  );

  // We need to know what type of plan to print
  $form['print'] = array(
    '#type' => 'hidden',
    '#value' => '',
  );
  return $form;
}

function exerciseplan_init_filters($all_terms, $form, $parent = 0) {
  $terms = array();
  foreach ($all_terms as $term) {
    if ($term->parents[0] == $parent) {
      $terms[$term->tid] = $term->name;
      $form = exerciseplan_init_filters($all_terms, $form, $term->tid);
    }
  }
  if (count($terms) > 0) {
    $terms[0] = t('All');
    $form['terms_' . $parent] = array(
      '#title' => ($parent == 0) ? t('Filter') : NULL,
      '#type' => 'select',
      '#options' => $terms,
      '#default_value' => 0,
      '#attributes' => ($parent == 0) ? NULL : array('class' => 'hidden'),
    );
  }
  return $form;
}

/**
 * The exercise plan's form submission handler
 */
function exerciseplan_form_submit($form, &$form_state) {
  include 'exerciseplan_print_rtf.inc';
  exerciseplan_print_rtf();
}